package com.googlecode.alfresco.repository.node;

import java.io.Serializable;
import java.util.Collection;

import org.alfresco.service.cmr.repository.NodeRef;
import org.alfresco.service.namespace.QName;

/**
 * Defines helper operations for working with repository nodes.
 *
 * @author Laurens Fridael
 *
 */
public interface NodeHelper {
	/**
	 * Obtains the path for a given NodeRef as a String.
	 *
	 * @param nodeRef
	 * @return
	 * @throws IllegalArgumentException
	 *             If nodeRef is null.
	 */
	public String getPath(NodeRef nodeRef);

	/**
	 * Obtains the values for a multi-valued property of a given NodeRef. If a property is single-valued, this method
	 * wraps the result in a collection.
	 *
	 * @param nodeRef
	 * @param property
	 * @return The property values as a Collection or null if the property is null or does not exist.
	 * @throws IllegalArgumentException
	 *             If nodeRef or property is null.
	 */
	public <T extends Serializable> Collection<T> getPropertyValues(NodeRef nodeRef, QName property);
}
